PlayerViewTypes class abstract final

Native PlatformView type identifiers registered per platform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

art → const String
Flutter Web Artplayer surface (HtmlElementView).
gsy → const String
Android-only GSY surface.
mpv → const String
Windows / Linux libmpv texture surface.
sg → const String
iOS / macOS SG surface.