SgBackgroundPlaybackPolicy class

Background / audio-interrupt policy (SGPlayer iOS).

Constructors

SgBackgroundPlaybackPolicy({bool pausesWhenInterrupted = true, bool pausesWhenEnteredBackground = false, bool pausesWhenEnteredBackgroundIfNoAudioTrack = true})
const
SgBackgroundPlaybackPolicy.fromMap(Map<Object?, Object?> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pausesWhenEnteredBackground → bool
final
pausesWhenEnteredBackgroundIfNoAudioTrack → bool
final
pausesWhenInterrupted → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited